<?php

namespace Slovocast\Domain\Entity;

use Slovocast\Domain\Entity;

class Channel
{
    use Entity;
    
    public function __construct(
        private string $name,
        private ?string $description = '',
        private ?string $link = '',
        private ?string $language = '',
        private ?string $copyright = '',
        private ?bool $explicit = false,
    ) {}

    public function getName(): string
    {
        return $this->name;
    }

    public function getDescription(): string
    {
        return $this->description;
    }

    public function getLink(): string
    {
        return $this->link;
    }

    public function getLanguage(): string
    {
        return $this->language;
    }

    public function getCopyright(): string
    {
        return $this->copyright;
    }

    /**
     * @param array $props The properties of the Channel model
     * @return Channel
     */
    public static function fromArray(array $props): Channel
    {
        $channel = new self(
            $props['name'],
            $props['description'] ?? '',
            $props['link'] ?? '',
            $props['language'] ?? '',
            $props['copyright'] ?? '',
            $props['explicit'] ?? false
        );

        if ($props['id']) {
            $channel->setId($props['id']);
        }

        if ($props['createdAt']) {
            $channel->setCreatedAt($props['createdAt']);
        }

        if ($props['updatedAt']) {
            $channel->setUpdatedAt($props['updatedAt']);
        }

        return $channel;
    }
}
